#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 heaps
version:              0.4.1
visibility:           public
id:                   heaps-0.4.1-IRybZIPuds3lIoZhb1hfl
key:                  heaps-0.4.1-IRybZIPuds3lIoZhb1hfl
license:              BSD-3-Clause
copyright:            (c) 2010-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/heaps/
synopsis:             Asymptotically optimal Brodal/Okasaki heaps.
description:
    Asymptotically optimal Brodal\/Okasaki bootstrapped skew-binomial heaps from the paper <http://citeseerx.ist.psu.edu/viewdoc/summary?doi=10.1.1.48.973 "Optimal Purely Functional Priority Queues">, extended with a '\''Foldable'\'' interface.

category:             Data Structures
abi:                  c89ff04949987b8e2a52f09f4d6b7fea
exposed:              True
exposed-modules:      Data.Heap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/heaps-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/heaps-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/heaps-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heaps
hs-libraries:         HSheaps-0.4.1-IRybZIPuds3lIoZhb1hfl
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-heaps/html/heaps.haddock
haddock-html:         /usr/share/doc/haskell-heaps/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

